# 设置防盗链（Referer）

OSS是按使用收费的服务，为了防止用户在OSS上的数据被其他人盗链，OSS支持
基于HTTP header中表头字段referer的防盗链方法。更多OSS防盗链请参考：
[OSS防盗链]({{doc/[8]用户手册/安全管理/设置防盗链.md}})

> 提示：
> 
> - 设置防盗链的示例代码在`sample/bucket_referer.go`。

## 设置Referer白名单

通过`Bucket.SetBucketReferer`设置Referer白名单，该函数有三个参数：
    
- bucketName 存储空间名称。 
- referers 访问白名单列表。一个bucket可以支持多个referer参数。eferer参数支持通配符"*"和"?"。
- allowEmptyReferer 指定是否允许referer字段为空的请求访问。默认配置为true。

```go
    import "github.com/aliyun/aliyun-oss-go-sdk/oss"
    
    client, err := oss.New("Endpoint", "AccessKeyId", "AccessKeySecret")
    if err != nil {
        // HandleError(err)
    }
    
    referers := []string{"http://www.aliyun.com",
                         "http://www.???.aliyuncs.com",
                         "http://www.*.com"}
    err = client.SetBucketReferer("my-bucket", referers, false)
    if err != nil {
        // HandleError(err)
    }
```

## 查看Referer白名单

通过`Bucket.GetBucketReferer`设置Referer白名单：

```go
    import "fmt"
    import "github.com/aliyun/aliyun-oss-go-sdk/oss"
    
    client, err := oss.New("Endpoint", "AccessKeyId", "AccessKeySecret")
    if err != nil {
        // HandleError(err)
    }
    
    refRes, err := client.GetBucketReferer("my-bucket")
    if err != nil {
        // HandleError(err)
    }
    fmt.Println("Referers:", refRes.RefererList, 
                "AllowEmptyReferer:", refRes.AllowEmptyReferer)
```

## 清空Referer白名单

清空Referer白名单，即把白名单设置成空，allowEmptyReferer为true：

```go
    import "github.com/aliyun/aliyun-oss-go-sdk/oss"
    
    client, err := oss.New("Endpoint", "AccessKeyId", "AccessKeySecret")
    if err != nil {
        // HandleError(err)
    }
    
    err = client.SetBucketReferer("my-bucket", []string{}, true)
    if err != nil {
        // HandleError(err)
    }
```
